Skip to contents

Information about Minka Place by Name Get information about Minka place by part of the place name.

Usage

mnk_places_byname(query)

Arguments

query

A string that is contained in the project name.

Value

A tibble with all the Minka places that contain the string with some details of those projects.

Examples

if (FALSE) { # \dontrun{
sant_feliu <- mnk_places_byname(query = "Sant Feliu")
} # }