Skip to contents

This is a convenience wrapper for mnk_obs to simplify downloading observations for a specific user, filtered by year and optionally by month and day.

Usage

mnk_user_obs(
  user_id,
  year,
  month = NULL,
  day = NULL,
  quiet = FALSE,
  limit_download = TRUE
)

Arguments

user_id

The numeric ID or login of the Minka user.

year

The numeric year for the query (required).

month

(Optional) The numeric month (1-12). Defaults to NULL (all months).

day

(Optional) The numeric day (1-31). Defaults to NULL (all days).

quiet

A logical value. If `TRUE`, all console messages will be suppressed.

limit_download

A logical value. If `TRUE` (default), the download is capped at 10,000 records per query subdivision. If `FALSE`, it attempts to download all records.

Value

A `tibble::tibble` containing the downloaded observation data.

Examples

if (FALSE) { # \dontrun{
# Download all observations for user ramonaervitje (user_id = 6) for the year 2024
# (up to the download limit)
user_data_2024 <- mnk_user_obs(user_id = 6, year = 2024)

# Download all observations for user 5678 for August 2025,
# attempting to get all records without a limit.
user_data_aug_2025 <- mnk_user_obs(user_id = 5678, year = 2025, month = 8, limit_download = FALSE)
} # }